package busi

import (
	"paas-golang/macros"
	"strconv"
)

type Event struct {
	writer Writer
}

type EventCustomMsg struct {
	EID       string
	CustomMsg string
}

func InitEvent(writer Writer) *Event {
	return &Event{writer: writer}
}

func (event *Event) GetEventCalendar(license string, did string, date, bindTag string) error {

	m := map[string]interface{}{
		"License": license,
		"DID":     did,
		"Date":    date,
		"BindTag": bindTag,
	}
	return event.writer.RemoteRequestZZYServer(macros.PASS_PATH_EVENT, m, macros.OPENAPI_ACTION_EVENT_QUERYCALENDAR, nil)
}

func (event *Event) GetEventList(license string, did string, date, bindTag string, pageSize uint16, queryType uint16, eid string) error {

	m := map[string]interface{}{
		"License":   license,
		"DID":       did,
		"Date":      date,
		"Eid":       eid,
		"PageSize":  strconv.Itoa(int(pageSize)),
		"QueryType": strconv.Itoa(int(queryType)),
		"BindTag":   bindTag,
	}
	return event.writer.RemoteRequestZZYServer(macros.PASS_PATH_EVENT, m, macros.OPENAPI_ACTION_EVENT_QUERYLIST, nil)
}

func (event *Event) UpdateEventInfo(license string, did string, eids []EventCustomMsg) error {

	m := map[string]interface{}{
		"License": license,
		"DID":     did,
		"Events":  eids,
	}
	return event.writer.RemoteRequestZZYServer(macros.PASS_PATH_EVENT, m, macros.OPENAPI_ACTION_EVENT_UPDATEEVENT, nil)
}

func (event *Event) DeleteEventInfo(license string, did string, eids []string) error {

	m := map[string]interface{}{
		"License": license,
		"DID":     did,
		"Events":  eids,
	}
	return event.writer.RemoteRequestZZYServer(macros.PASS_PATH_EVENT, m, macros.OPENAPI_ACTION_EVENT_DELETEEVENT, nil)
}

func (event *Event) GetEventDetail(license string, did string, eid string) error {

	m := map[string]interface{}{
		"License": license,
		"DID":     did,
		"Eid":     eid,
	}
	return event.writer.RemoteRequestZZYServer(macros.PASS_PATH_EVENT, m, macros.OPENAPI_ACTION_EVENT_QUERYEVENTDETAIL, nil)
}
