package busi

import (
	"paas-golang/macros"
	"strconv"
)

type Preset struct {
	writer Writer
}

type EncInfo struct {
	EncType uint16 `json:"EncType,string"`
	EncKey  string
	EncLoad string
}

func InitPreset(writer Writer) *Preset {
	return &Preset{writer: writer}
}

func (preset *Preset) PrefetchURL(license string, did string, num uint16) error {

	m := map[string]interface{}{
		"License": license,
		"DID":     did,
		"Num":     strconv.Itoa(int(num)),
	}
	return preset.writer.RemoteRequestZZYServer(macros.PASS_PATH_PRESET, m, macros.OPENAPI_ACTION_PRESET_PREFETCH, nil)
}

func (preset *Preset) Report(license string, did string, fileid string, path string, bucket string, filesize uint64, encInfo *EncInfo) error {

	m := map[string]interface{}{
		"License":  license,
		"DID":      did,
		"FileID":   fileid,
		"Path":     path,
		"Bucket":   bucket,
		"FileSize": strconv.Itoa(int(filesize)),
	}

	if encInfo != nil {
		m["EncInfo"] = encInfo
	}

	return preset.writer.RemoteRequestZZYServer(macros.PASS_PATH_PRESET, m, macros.OPENAPI_ACTION_PRESET_REPORT, nil)
}

func (preset *Preset) GetPresetFileDetail(license string, did string, fileid string) error {

	m := map[string]interface{}{
		"License": license,
		"DID":     did,
		"FileID":  fileid,
	}

	return preset.writer.RemoteRequestZZYServer(macros.PASS_PATH_PRESET, m, macros.OPENAPI_ACTION_PRESET_QUERYFILEDETAIL, nil)
}

func (preset *Preset) DeletePresetFile(license string, did string, fileid string) error {

	m := map[string]interface{}{
		"License": license,
		"DID":     did,
		"FileID":  fileid,
	}

	return preset.writer.RemoteRequestZZYServer(macros.PASS_PATH_PRESET, m, macros.OPENAPI_ACTION_PRESET_DELETEPRESETFILE, nil)
}
