package crypto

import (
	"crypto/aes"
	"crypto/cipher"
	"errors"
)

func AesEncryptOutBase64(origData, key, iv []byte) (string, error) {
	encbuf, err := AesEncrypt(origData, key, iv)
	if err != nil {
		return "", err
	}
	bs64 := ByteToBase64(encbuf)
	return bs64, nil
}

func Base64AesDecodeToByte(bs64 string, key, iv []byte) ([]byte, error) {
	decbuf := Base64ToByte(bs64)
	if decbuf == nil {
		return nil, errors.New("Base64ToByte Error!")
	}
	obuf, err := AesDecrypt(decbuf, key, iv)
	if err != nil {
		return nil, err
	}
	return obuf, nil
}

func AesEncrypt(origData, key, iv []byte) ([]byte, error) {
	block, err := aes.NewCipher(key)
	if err != nil {
		return nil, err
	}

	blockSize := block.BlockSize()
	origData = PKCS5Padding(origData, blockSize)
	blockMode := cipher.NewCBCEncrypter(block, iv)
	crypted := make([]byte, len(origData))
	blockMode.CryptBlocks(crypted, origData)
	return crypted, nil
}

func AesDecrypt(crypted, key, iv []byte) ([]byte, error) {

	if len(crypted) == 0 {
		return nil, errors.New("Crypted is null. ")
	}

	block, err := aes.NewCipher(key)
	if err != nil {
		return nil, err
	}

	if len(crypted)%block.BlockSize() != 0 {
		return nil, errors.New("crypto/cipher: input not full blocks")
	}

	blockMode := cipher.NewCBCDecrypter(block, iv)
	origData := make([]byte, len(crypted))
	blockMode.CryptBlocks(origData, crypted)

	if len(origData) == 0 {
		return nil, errors.New("OrigData is null. ")
	}

	origData = PKCS5UnPadding(origData)

	if origData == nil {
		return origData, errors.New("UnPadding Error! ")
	}

	return origData, nil
}
