package http

import "time"

type Options struct {
	HeaderMap             map[string]string // Default: nil
	ResponseHeaderTimeout time.Duration     // Default: 3
	TimeOut               time.Duration     // Default: 3
	KeepAlive             time.Duration     // Default: 3
	TLSHandshakeTimeout   time.Duration     // Default: 3
	InsecureSkipVerify    bool              // Default: false
	DisableKeepAlives     bool              // Default: true
}
type Option func(*Options)

func WithHeaderMap(m map[string]string) Option {
	return func(o *Options) {
		o.HeaderMap = m
	}
}

//Units: sec
func WithResponseHeaderTimeout(n int) Option {
	return func(o *Options) {
		o.ResponseHeaderTimeout = time.Duration(n)
	}
}

//Units: sec
func WithTimeOut(timeout time.Duration) Option {
	return func(o *Options) {
		o.TimeOut = timeout
	}
}

//Units: sec
func WithKeepAlive(n int) Option {
	return func(o *Options) {
		o.KeepAlive = time.Duration(n)
	}
}

func WithInsecureSkipVerify(skipVerify bool) Option {
	return func(o *Options) {
		o.InsecureSkipVerify = skipVerify
	}
}

func WithDisableKeepAlives(disableKeepAlives bool) Option {
	return func(o *Options) {
		o.DisableKeepAlives = disableKeepAlives
	}
}
